@@ -1,7 +1,6 @@
 pickFields<-function(sas,picks=c("casenum","reg","race","sex","agedx","yrbrth",
 				"seqnum","yrdx","histo2","histo3","radiatn",
 				"agerec","ICD9","histrec","cssO3","numprims","survtm","COD") ){
-	sas=getFields()
 	subsas=sas
 	rownames(subsas)<-subsas$names
 	subsas=subsas[picks,]
@@ -16,11 +15,12 @@ pickFields<-function(sas,picks=c("casenum","reg","race","sex","agedx","yrbrth",
 		middle$names=c("srvy","srvm")
 		rownames(middle)=c("srvy","srvm")
 		subsas=rbind(top,middle,bottom)
+		N=N+1
 	}
-	subsas=cbind(subsas,type="integer")  # db file size increases if this is set to strings
+	subsas=cbind(subsas,type="integer",stringsAsFactors=FALSE)  # db file size increases if this is set to strings
 	# the following appear to be the only two columns with letters in their names
-	if("siteo2" %in% subsas$names) subsas[which(subsas$names=="siteo2"),"type"]="string"
-	if("ICD10" %in% subsas$names) subsas[which(subsas$names=="ICD10"),"type"]="string"
+	if("siteo2" %in% subsas$names) subsas["siteo2","type"]="string"
+	if("ICD10" %in% subsas$names) subsas["ICD10","type"]="string"
 	if (picks[1]=="casenum") outdf=subsas[1,,drop=F] else  
 		outdf=data.frame(start=1,width=subsas$start[1]-1,names=" ",desc=" ",type="string")
 	for (i in 2:N) 
